'
' Copyright (c) 2001-2010 by PDFTron Systems Inc. All Rights Reserved.
'

Imports System

Imports pdftron
Imports pdftron.Common
Imports pdftron.Filters
Imports pdftron.SDF
Imports pdftron.PDF

' The following sample illustrates how to read/write a PDF document from/to 
' a memory buffer.  This is useful for applications that work with dynamic PDF
' documents that don't need to be saved/read from a disk.
Module Module1

    Sub Main()

        PDFNet.Initialize()

        ' Relative path to the folder containing test files.
        Dim input_path As String = "../../../TestFiles/"
        Dim output_path As String = "../../../TestFiles/Output/"

        Try
            ' Read a PDF document in a memory buffer.
            Dim file As StdFile = New StdFile(input_path + "tiger.pdf", StdFile.OpenMode.e_read_mode)
            file.Seek(0, Filter.ReferencePos.e_end)
            Dim file_sz As Integer = file.Tell()
            file.Seek(0, Filter.ReferencePos.e_begin)

            Dim file_reader As FilterReader = New FilterReader(file)
            Dim mem As MemoryFilter = New MemoryFilter(file_sz, False)
            Dim file_buff(file_sz) As Byte
            file_reader.Read(file_buff)

            Dim doc As PDFDoc = New PDFDoc(file_buff, file_sz)
            doc.InitSecurityHandler()
            Dim num_pages As Integer = doc.GetPageCount()

            Dim writer As ElementWriter = New ElementWriter
            Dim reader As ElementReader = New ElementReader
            Dim element As Element

            ' Perform some document editing ...
            ' Here we simply copy all elements from one page to another.
            Dim i As Integer
            For i = 1 To num_pages Step 1
                Dim pg As Page = doc.GetPage(2 * i - 1)
                reader.Begin(pg)
                Dim new_page As Page = doc.PageCreate(pg.GetMediaBox())
                doc.PageInsert(doc.GetPageIterator(2 * i), new_page)

                writer.Begin(new_page)
                element = reader.Next()
                While (Not IsNothing(element))      ' Read page contents
                    writer.WriteElement(element)
                    element = reader.Next()
                End While

                writer.End()
                reader.End()
            Next i

            doc.Save(output_path + "doc_memory_edit.pdf", SDF.SDFDoc.SaveOptions.e_remove_unused)

            ' Save the document to a memory buffer.
            Dim buf(0) As Byte
            Dim buf_sz As Integer = 1
            doc.Save(buf, buf_sz, SDF.SDFDoc.SaveOptions.e_remove_unused)


            ' Write the contents of the buffer to the disk
            Dim outfile As StdFile = New StdFile(output_path + "doc_memory_edit.txt", StdFile.OpenMode.e_write_mode)
            Dim fwriter As FilterWriter = New FilterWriter(outfile)
            fwriter.WriteBuffer(buf)
            fwriter.Flush()

            ' Read some data from the file stored in memory
            reader.Begin(doc.GetPage(1))
            element = reader.Next()
            While (Not IsNothing(element))   ' Read page contents
                If element.GetType() = element.Type.e_path Then
                    Console.Write("Path, ")
                End If

                element = reader.Next()
            End While
			reader.End()

			' Calling Dispose() on ElementReader/Writer/Builder can result in increased performance and lower memory consumption.
			reader.Dispose()
			writer.Dispose()

            Console.WriteLine("")
            Console.WriteLine("")
            Console.WriteLine("Done. Result saved in doc_memory_edit.pdf and doc_memory_edit.txt ...")
			doc.Close()

		Catch ex As PDFNetException
			Console.WriteLine(ex.Message)
		Catch ex As Exception
			MsgBox(ex.Message)
		End Try

		PDFNet.Terminate()
    End Sub
End Module
