// ---------------------------------------------------------------------------------------
// Copyright (c) 2001-2010 by PDFTron Systems Inc. All Rights Reserved.
// Consult legal.txt regarding legal and license information.
//---------------------------------------------------------------------------------------

using System;
using System.IO;
using System.Drawing;
using System.Drawing.Printing;
using System.Drawing.Drawing2D;
using System.Drawing.Imaging;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;

using pdftron;
using pdftron.Common;
using pdftron.Filters;
using pdftron.SDF;
using pdftron.PDF;

namespace PDFViewCS
{
	/// <summary>
	/// Summary description for PDFViewSecurityHandler.
	/// </summary>
	class PDFViewSecurityHandler : StdSecurityHandler
	{
		public PDFViewSecurityHandler (Int32 key_len, Int32 enc_code) : base(key_len, enc_code) {}
		public PDFViewSecurityHandler (PDFViewSecurityHandler s) : base(s) {}

		// In this callback ask the user for password/authorization data. 
		// This may invlove a dialog box used to collect authorization data or something else.
		override public bool GetAuthorizationData (SecurityHandler.Permission p) 
		{ 
			AuthorizeDlg dlg = new AuthorizeDlg();
			if (dlg.ShowDialog() == DialogResult.OK) {
				InitPassword(dlg.pass.Text);
				return true;
			}
			else {
				return false;
			}
		}

		// This callback could be used to customize security handler preferences.
		override public bool EditSecurityData(SDFDoc doc) { return false; }

		// This callback is used when authorization process fails. 
		override public void AuthorizeFailed() 
		{
			MessageBox.Show("Authorize failed...", "PDFView Error");
		}

		public static SecurityHandler Create(String name, Int32 key_len, Int32 enc_code) { return new PDFViewSecurityHandler(key_len, enc_code); }

		override public SecurityHandler Clone() { return new PDFViewSecurityHandler(this); }
	}
}
